@@ -26,7 +26,7 @@ function remove_all_ve_aliases()
 	local ve_if_name
 	local ve_if
 
-	ve_if_name=`grep "^venet0_" ${CFGFILE}.bak | cut -d'=' -f1`
+	ve_if_name=`grep "^${VENET_DEV}_" ${CFGFILE}.bak | cut -d'=' -f1`
 
 	for ve_if in ${ve_if_name}; do
 	    /etc/rc.d/network ifdown ${ve_if} 2>/dev/null
@@ -44,10 +44,10 @@ function setup_network()
     fi
 
     # create venet0 and routes
-    if ! grep -qe "^venet0=" ${CFGFILE}.bak 2>/dev/null; then
-	put_param "${CFGFILE}.bak" "venet0" "venet0 127.0.0.1 netmask 255.255.255.255 broadcast 0.0.0.0"
-	add_param3 "${CFGFILE}.bak" "INTERFACES" "venet0"
-	put_param "${CFGFILE}.bak" "rt_default" "default dev venet0"
+    if ! grep -qe "^${VENET_DEV}=" ${CFGFILE}.bak 2>/dev/null; then
+	put_param "${CFGFILE}.bak" "${VENET_DEV}" "${VENET_DEV} 127.0.0.1 netmask 255.255.255.255 broadcast 0.0.0.0"
+	add_param3 "${CFGFILE}.bak" "INTERFACES" "${VENET_DEV}"
+	put_param "${CFGFILE}.bak" "rt_default" "default dev ${VENET_DEV}"
 	add_param3 "${CFGFILE}.bak" "ROUTES" "rt_default"
     fi
 }
@@ -55,10 +55,11 @@ function setup_network()
 function create_config()
 {
 	local ip=$1
-	local ifnum=$2
+	local netmask=$2
+	local ifnum=$3
 	# add venet0 alias to rc.conf
 	put_param "${CFGFILE}.bak" "${VENET_DEV}_${ifnum}" \
-		"${VENET_DEV}:${ifnum} ${ip} netmask 255.255.255.255 broadcast 0.0.0.0"
+		"${VENET_DEV}:${ifnum} ${ip} netmask ${netmask} broadcast 0.0.0.0"
 
 	# add venet0 alias to INTERFACES array
 	add_param3 "${CFGFILE}.bak" "INTERFACES" "${VENET_DEV}_${ifnum}"
@@ -86,8 +87,7 @@ function get_free_aliasid()
 
 function add_ip()
 {
-	local ip
-	local found
+	local ipm
 	local add
 	local iface
 
@@ -99,13 +99,13 @@ function add_ip()
 
 	setup_network
 
-	for ip in ${IP_ADDR}; do
-		found=
-		if grep -e "\\<${ip}\\>" >/dev/null 2>&1  ${CFGFILE}.bak; then
+	for ipm in ${IP_ADDR}; do
+		ip_conv $ipm
+		if grep -e "\\<${_IP}\\>" >/dev/null 2>&1  ${CFGFILE}.bak; then
 			continue
 		fi
 		get_free_aliasid
-		create_config ${ip} ${IFNUM}
+		create_config "${_IP}" "${_NETMASK}" "${IFNUM}"
 	done
 
 	mv -f ${CFGFILE}.bak ${CFGFILE}
