@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2010, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2012, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -93,8 +93,8 @@ struct Cveinfo {
 	char *description;
 	char *ostemplate;
 	char *ip;
-	char *ve_private;
-	char *ve_root;
+	char *private;
+	char *root;
 	struct Cubc *ubc;
 	struct Cquota *quota;
 	struct Ccpustat *cpustat;
@@ -103,7 +103,11 @@ struct Cveinfo {
 	int status;
 	int hide;
 	int onboot;
+	int cpunum;
 	unsigned long *bootorder;
+	int layout; // VE_LAYOUT_*
+	unsigned long long features_mask;
+	unsigned long long features_known;
 };
 
 #define RES_NONE	0
@@ -113,6 +117,7 @@ struct Cveinfo {
 #define RES_IP		4
 #define RES_CPUSTAT	5
 #define RES_CPU		6
+#define RES_CPUNUM	7
 
 struct Cfield {
 	char *name;
