@@ -379,7 +379,7 @@ static int parse_features(env_param_t *env, char *val)
 	char *token;
 	struct feature_s *feat;
 
-	for_each_strtok(token, val, "\t ") {
+	for_each_strtok(token, val, "\t ,") {
 		feat = find_feature(token);
 		if (!feat) {
 			logger(0, 0, "Warning: Unknown feature: %s", token);
@@ -401,7 +401,7 @@ static void store_features(unsigned long long mask, unsigned long long known,
 	int r;
 
 	r = snprintf(buf, sizeof(buf) - 1, "%s=\"", conf->name);
-	features_mask2str(mask, known, buf + r, sizeof(buf) - r - 2);
+	features_mask2str(mask, known, " ", buf + r, sizeof(buf) - r - 2);
 	strcat(buf, "\"");
 	add_str_param(conf_h, buf);
 }
@@ -441,7 +441,7 @@ static int parse_iptables(env_param_t *env, char *val)
 	struct iptables_s *ipt;
 	int ret = 0;
 
-	for_each_strtok(token, val, "\t ") {
+	for_each_strtok(token, val, "\t ,") {
 		ipt = find_ipt(token);
 		if (!ipt) {
 			logger(-1, 0, "Warning: Unknown iptable module: %s,"
@@ -607,7 +607,7 @@ static int parse_meminfo(meminfo_param *param, const char *val)
 	if ((mode != VE_MEMINFO_NONE && ret !=2) ||
 	    (mode == VE_MEMINFO_NONE && ret == 2))
 		return ERR_INVAL;
-	if((mode != VE_MEMINFO_NONE) && meminfo_val == 0)
+	if ((mode != VE_MEMINFO_NONE) && meminfo_val == 0)
 		return ERR_INVAL;
 	param->mode = mode;
 	param->val = meminfo_val;
@@ -661,6 +661,13 @@ static int parse_vswap(ub_param *ub, const char *val, int id)
 	const char *tail;
 	unsigned long long tmp;
 
+	/* If current kernel is not vswap-capable, cry out loud */
+	if (!is_vswap_mode()) {
+		logger(-1, 0, "Error: kernel does not support vswap, "
+				"unable to use --ram/--swap parameters");
+		return ERR_OTHER;
+	}
+
 	/* Translate from VSwap ('easy') to UBC parameter */
 	switch(id) {
 		case PARAM_RAM:
@@ -676,7 +683,7 @@ static int parse_vswap(ub_param *ub, const char *val, int id)
 	if (conf_get_by_id(config, id) == NULL)
 		return ERR_OTHER;
 
-	tail = parse_ul_sfx(val, &tmp, _page_size);
+	tail = parse_ul_sfx(val, &tmp, 1);
 	if (tail == NULL)
 		return ERR_INVAL;
 	if (*tail != '\0')
@@ -747,7 +754,7 @@ static int parse_cap(char *str, cap_param *cap)
 	char cap_nm[128];
 	unsigned long *mask;
 
-	for_each_strtok(token, str, "\t ") {
+	for_each_strtok(token, str, "\t ,") {
 		if ((p = strrchr(token, ':')) == NULL)
 			goto err;
 		if (!strcmp(p + 1, "off"))
@@ -786,9 +793,10 @@ static int store_cap(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 	if (!cap->on && !cap->off)
 		return 0;
 	p = buf;
-	p += sprintf(buf, "%s=", conf->name);
+	p += sprintf(buf, "%s=\"", conf->name);
 	len = buf + sizeof(buf) - p - 1;
-	build_cap_str(cap, &old_p->res.cap, p, len);
+	build_cap_str(cap, &old_p->res.cap, " ", p, len);
+	strcat(p, "\"");
 	add_str_param(conf_h, buf);
 
 	return 0;
@@ -1085,8 +1093,7 @@ static int parse_dev(vps_param *vps_p, char *val)
 		if (parse_devices_str(token, &dev))
 			return ERR_INVAL;
 		if (add_dev_param(&vps_p->res.dev, &dev)) {
-			if (dev.name)
-				free(dev.name);
+			free(dev.name);
 			return ERR_NOMEM;
 		}
 	}
@@ -1121,11 +1128,11 @@ static int store_dev(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 		major = major(res->dev);
 		minor = minor(res->dev);
 		if (res->use_major) {
-			r = snprintf(sp, ep - sp,"%c:%d:all:%s ",
+			r = snprintf(sp, ep - sp, "%c:%d:all:%s ",
 				S_ISBLK(res->type) ? 'b' : 'c', major,
 				devperm2str(res->mask));
 		} else {
-			r = snprintf(sp, ep - sp,"%c:%d:%d:%s ",
+			r = snprintf(sp, ep - sp, "%c:%d:%d:%s ",
 				S_ISBLK(res->type) ? 'b' : 'c', major, minor,
 				devperm2str(res->mask));
 		}
@@ -1204,8 +1211,7 @@ static int parse_devnodes(vps_param *vps_p, char *val)
 		if (parse_devnodes_str(token, &dev))
 			return ERR_INVAL;
 		if (add_dev_param(&vps_p->res.dev, &dev)) {
-			if (dev.name)
-				free(dev.name);
+			free(dev.name);
 			return ERR_NOMEM;
 		}
 	}
@@ -1236,7 +1242,7 @@ static int store_devnodes(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 			continue;
 		if (sp == buf)
 			sp += snprintf(buf, sizeof(buf), "%s=\"", conf->name);
-		r = snprintf(sp, ep - sp,"%s:%s ", res->name,
+		r = snprintf(sp, ep - sp, "%s:%s ", res->name,
 			devperm2str(res->mask));
 		sp += r;
 		if ((r < 0) || (sp >= ep))
@@ -1454,7 +1460,7 @@ static int add_netif_param(veth_param *veth, int opt, char *str)
 	switch (opt) {
 	case PARAM_NETIF_IFNAME:
 		if (dev->dev_name_ve[0] != 0) {
-			logger(-1, 0,"Multiple use of"
+			logger(-1, 0, "Multiple use of"
 				" --ifname option not allowed");
 			return ERR_INVAL;
 		}
@@ -1483,7 +1489,7 @@ static int add_netif_param(veth_param *veth, int opt, char *str)
 		break;
 	case PARAM_NETIF_BRIDGE:
 		if (dev->dev_bridge[0] != 0) {
-			logger(-1, 0,"Multiple use of"
+			logger(-1, 0, "Multiple use of"
 				" --bridge option not allowed");
 			return ERR_INVAL;
 		}
@@ -2184,6 +2190,9 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_SNAPSHOT_DESC:
 		ret = conf_parse_str(&vps_p->snap.desc, val);
 		break;
+	case PARAM_SNAPSHOT_SKIP_SUSPEND:
+		vps_p->snap.flags |= SNAPSHOT_SKIP_SUSPEND;
+		break;
 	case PARAM_IGNORED:
 		/* Well known but ignored parameter */
 		break;
@@ -2717,8 +2726,7 @@ void free_vps_param(vps_param *param)
 
 #define MERGE_STR(x)						\
 	if ((src->x) != NULL) {					\
-		if ((dst->x) != NULL)				\
-			free(dst->x);				\
+		free(dst->x);					\
 		dst->x = strdup(src->x);			\
 	}
 
