@@ -24,7 +24,6 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <sys/stat.h>
 #include <string.h>
 #include <grp.h>
 #include <sys/ioctl.h>
@@ -32,6 +31,7 @@
 #include <sys/personality.h>
 #include <linux/reboot.h>
 #include <sys/mount.h>
+#include <sys/utsname.h>
 
 #include "vzerror.h"
 #include "res.h"
@@ -213,7 +213,6 @@ void vz_close(vps_handler *h)
 int vps_is_run(vps_handler *h, envid_t veid)
 {
 	int ret;
-	int errno;
 
 	if (veid == 0)
 		return 1;
@@ -449,7 +448,7 @@ static int vz_real_env_create(vps_handler *h, envid_t veid, vps_res *res,
 		return ret;
 	if ((ret = vz_setluid(veid)))
 		return ret;
-	if ((ret = setup_resource_management(h, veid, res)))
+	if ((ret = set_ublimit(h, veid, &res->ub)))
 		return ret;
 	/* Create another process for proper resource accounting */
 	if ((pid = fork()) < 0) {
@@ -471,6 +470,106 @@ env_err:
 	return 0;
 }
 
+#define MAX_OSREL_LEN 128
+
+static void read_osrelease_conf(const char *dist, char *osrelease)
+{
+	FILE *f;
+	char str[MAX_OSREL_LEN];
+	char var[MAX_OSREL_LEN];
+	char value[MAX_OSREL_LEN];
+	int dlen = strlen(dist);
+
+	if ((f = fopen(OSRELEASE_CFG, "r")) == NULL) {
+		logger(-1, errno, "Can't open file " OSRELEASE_CFG);
+		return;
+	}
+	while (fgets(str, sizeof(str) - 1, f) != NULL) {
+		if (str[0] == '#')
+			continue;
+		if (sscanf(str, " %s %s ", var, value) != 2)
+			continue;
+		if (strncmp(var, dist, strnlen(var, dlen)) == 0) {
+			strcpy(osrelease, value);
+			break;
+		}
+	}
+	fclose(f);
+	return;
+}
+
+#define KVER(a, b, c) (((a) << 16) + ((b) << 8) + (c))
+static int compare_osrelease(const char *cur, const char *min)
+{
+	int cur_a, cur_b, cur_c;
+	int min_a, min_b, min_c;
+	int ret;
+
+	ret = sscanf(cur, "%d.%d.%d", &cur_a, &cur_b, &cur_c);
+	if (ret != 3) {
+		logger(-1, 0, "Unable to parse kernel osrelease (%s)", cur);
+		return -1;
+	}
+
+	ret = sscanf(min, "%d.%d.%d", &min_a, &min_b, &min_c);
+	if (ret != 3) {
+		logger(-1, 0, "Unable to parse value (%s) from "
+				OSRELEASE_CFG, min);
+		return -1;
+	}
+
+	if (KVER(cur_a, cur_b, cur_c) < KVER(min_a, min_b, min_c))
+		return 1; /* Current version is too old */
+
+	return 0;
+}
+#undef KVER
+
+/** Find out if a container needs setting osrelease,
+  * and set it if needed. */
+static void get_osrelease(vps_res *res)
+{
+	const char *dist;
+	char osrelease[MAX_OSREL_LEN] = "";
+	struct utsname uts;
+	char *suffix;
+	int len;
+
+	dist = get_dist_name(&res->tmpl);
+	if (!dist)
+		return;
+
+	read_osrelease_conf(dist, osrelease);
+	if (osrelease[0] == '\0')
+		return;
+
+	logger(1, 0, "Found osrelease %s for dist %s", osrelease, dist);
+
+	/* Check if current osrelease is sufficient */
+	if (uname(&uts) != 0) {
+		logger(-1, errno, "Error in uname()");
+		return;
+	}
+
+	if (compare_osrelease(uts.release, osrelease) < 1)
+		/* -1: error; 0: current version is good enough */
+		return;
+
+	/* Yes we need to set osrelease for this container */
+
+	/* Make version look like our kernel, i.e. add suffix
+	 * like -028stab078.10 to osrelease
+	 */
+	if ((suffix = strchr(uts.release, '-')) != NULL) {
+		len = sizeof(osrelease) - strlen(osrelease);
+		strncat(osrelease, suffix, len);
+		osrelease[sizeof(osrelease) - 1] = 0;
+	}
+
+	logger(1, 0, "Set osrelease=%s", osrelease);
+	res->env.osrelease = strdup(osrelease);
+}
+
 int vz_env_create(vps_handler *h, envid_t veid, vps_res *res,
 		int wait_p[2], int old_wait_p[2], int err_p[2],
 				env_create_FN fn, void *data)
@@ -587,91 +686,6 @@ static void fix_cpu(cpu_param *cpu)
 	}
 }
 
-#define SBIN_INIT "/sbin/init"
-#define UPSTART_INIT "/lib/upstart/init"
-#define UPSTART "upstart"
-#define SYSTEMD "systemd"
-#define FEDORA_RELEASE "/etc/fedora-release"
-#define DEV_CONSOLE "/dev/console"
-#define DEV_NULL "/dev/null"
-
-static int fix_ve_systemd(const char *root)
-{
-	struct stat st;
-	char file[STR_SIZE];
-	char dest[STR_SIZE];
-
-	/* Check if init is systemd */
-	snprintf(file, STR_SIZE - 1, "%s/" SBIN_INIT, root);
-	if (lstat(file, &st) != 0)
-		return 0; /* Some error -- giving up */
-	if (!S_ISLNK(st.st_mode))
-		return 0; /* Not a symlink, so not systemd */
-	if (readlink(file, dest, STR_SIZE - 1) < 0)
-		return 0; /* Some error -- giving up */
-	if (strstr(dest, SYSTEMD) == NULL)
-		return 0; /* Not systemd */
-
-	logger(2, 0, "systemd init found, changing to upstart");
-	snprintf(dest, STR_SIZE - 1, "%s/" UPSTART_INIT, root);
-	if (stat(dest, &st) != 0)
-		goto err;
-	if (unlink(file) != 0)
-		goto err;
-	if (symlink(UPSTART_INIT, file) != 0)
-		goto err;
-
-	return 0;
-err:
-	logger(-1, errno, "Failed to set upstart as init. "
-			"Please install upstart into this CT.");
-	return -1;
-}
-
-static int fix_ve_devconsole(const char *root)
-{
-	char file[STR_SIZE];
-	char dest[STR_SIZE];
-	struct stat st;
-
-	snprintf(file, STR_SIZE - 1, "%s/" DEV_CONSOLE , root);
-	if (lstat(file, &st) == 0 && S_ISLNK(st.st_mode))
-		return 0; /* already fixed */
-
-	/* Check that it's Fedora */
-	snprintf(file, STR_SIZE - 1, "%s/" FEDORA_RELEASE , root);
-	if (stat(file, &st) != 0)
-		return 0; /* not Fedora */
-
-	/* Check if init is upstart */
-	snprintf(file, STR_SIZE - 1, "%s/" SBIN_INIT , root);
-	if (lstat(file, &st) != 0)
-		return 0; /* Some error -- giving up */
-	if (!S_ISLNK(st.st_mode))
-		return 0; /* Not a symlink, so not upstart */
-	if (readlink(file, dest, STR_SIZE - 1) < 0)
-		return 0; /* Some error -- giving up */
-	if (strstr(dest, UPSTART) == NULL)
-		return 0; /* Not upstart */
-
-	/* For upstart 1.2 to work in CT,
-	 * /dev/console should point to /dev/null
-	 */
-	snprintf(file, STR_SIZE - 1, "%s/" DEV_CONSOLE, root);
-	if (unlink(file) != 0)
-		if (errno != ENOENT) {
-			logger(-1, errno, "Failed to remove %s", file);
-			return -1;
-		}
-
-	if (symlink(DEV_NULL, file) != 0) {
-		logger(-1, errno, "Failed to symlink %s -> " DEV_NULL, file);
-		return -1;
-	}
-
-	return 0;
-}
-
 int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	skipFlags skip, struct mod_action *mod,
 	env_create_FN fn, void *data)
@@ -705,10 +719,12 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 	if (ret)
 		return ret;
 	logger(0, 0, "Starting container ...");
+	/* if CT is mounted -- umount first, to cleanup mount state */
 	if (vps_is_mounted(res->fs.root)) {
-		/* if CT is mounted -- umount first, to cleanup mount state */
 		vps_umount(h, veid, &res->fs, skip);
 	}
+	else if (ploop && (is_image_mounted(res->fs.private)))
+		vzctl_umount_image(res->fs.private);
 	if (!vps_is_mounted(res->fs.root)) {
 		/* increase quota to perform setup */
 		if (!ploop)
@@ -718,11 +734,6 @@ int vps_start_custom(vps_handler *h, envid_t veid, vps_param *param,
 		if (!ploop)
 			quota_inc(&res->dq, -100);
 	}
-	/* Fedora 14/15 hacks */
-	if (fix_ve_devconsole(res->fs.root) != 0)
-		return VZ_FS_BAD_TMPL;
-	if (fix_ve_systemd(res->fs.root) != 0)
-		return VZ_FS_BAD_TMPL;
 
 	if (pipe(wait_p) < 0) {
 		logger(-1, errno, "Can not create pipe");
