@@ -22,7 +22,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/mount.h>
-#include <sys/param.h>
+#include <limits.h>
 #include <fcntl.h>
 #include <errno.h>
 #include <string.h>
@@ -63,17 +63,40 @@ int is_ploop_supported(void)
 	return (ploop_getdevice(&minor) == 0);
 }
 
+int is_image_mounted(const char *ve_private)
+{
+	int ret;
+	char dev[64];
+	char fname[PATH_MAX];
+	struct ploop_disk_images_data *di;
+
+	di = ploop_alloc_diskdescriptor();
+	if (di == NULL)
+		return -1;
+	GET_DISK_DESCRIPTOR(fname, ve_private);
+	ret = ploop_read_diskdescriptor(fname, di);
+	if (ret) {
+		logger(-1, 0, "Failed to read %s", fname);
+		ploop_free_diskdescriptor(di);
+		return -1;
+	}
+	ret = ploop_get_dev(di, dev, sizeof(dev));
+	ploop_free_diskdescriptor(di);
+
+	return (ret == 0);
+}
+
 int vzctl_mount_image(const char *ve_private, struct vzctl_mount_param *param)
 {
 	int ret;
 	struct ploop_mount_param mount_param = {};
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	ret = ploop_read_diskdescriptor(fname, di);
 	if (ret) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -99,14 +122,14 @@ int vzctl_mount_image(const char *ve_private, struct vzctl_mount_param *param)
 int vzctl_umount_image(const char *ve_private)
 {
 	int ret;
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
 
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	ret = ploop_read_diskdescriptor(fname, di);
 	if (ret) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -129,8 +152,8 @@ int vzctl_create_image(const char *ve_private,
 {
 	int ret = 0;
 	struct ploop_create_param create_param = {};
-	char dir[MAXPATHLEN];
-	char image[MAXPATHLEN];
+	char dir[PATH_MAX];
+	char image[PATH_MAX];
 
 	snprintf(dir, sizeof(dir), "%s/" VZCTL_VE_ROOTHDD_DIR, ve_private);
 	ret = make_dir_mode(dir, 1, 0700);
@@ -157,13 +180,13 @@ int vzctl_create_image(const char *ve_private,
 int vzctl_convert_image(const char *ve_private, int mode)
 {
 	int ret;
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	ret = ploop_read_diskdescriptor(fname, di);
 	if (ret) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -185,7 +208,7 @@ int vzctl_resize_image(const char *ve_private, unsigned long long newsize)
 	int ret;
 	struct ploop_disk_images_data *di;
 	struct ploop_resize_param param;
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 
 	if (ve_private == NULL) {
 		logger(-1, 0, "Failed to resize image: "
@@ -193,10 +216,13 @@ int vzctl_resize_image(const char *ve_private, unsigned long long newsize)
 		return VZCTL_E_RESIZE_IMAGE;
 	}
 
+	if (check_ploop_size(newsize) < 0)
+		return VZ_DISKSPACE_NOT_SET;
+
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	ret = ploop_read_diskdescriptor(fname, di);
 	if (ret) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -221,7 +247,7 @@ int vzctl_get_ploop_dev(const char *mnt, char *out, int len)
 
 int vzctl_create_snapshot(const char *ve_private, const char *guid)
 {
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 	int ret;
 	struct ploop_snapshot_param param = {};
@@ -234,7 +260,7 @@ int vzctl_create_snapshot(const char *ve_private, const char *guid)
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	if (ploop_read_diskdescriptor(fname, di)) {
 		logger(-1, 0, "Failed to read %s", fname);
 		ploop_free_diskdescriptor(di);
@@ -255,7 +281,7 @@ int vzctl_create_snapshot(const char *ve_private, const char *guid)
 
 int vzctl_delete_snapshot(const char *ve_private, const char *guid)
 {
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 	int ret;
 
@@ -267,7 +293,7 @@ int vzctl_delete_snapshot(const char *ve_private, const char *guid)
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	if (ploop_read_diskdescriptor(fname, di)) {
 		logger(-1, 0, "Failed to read %s", fname);
 		ploop_free_diskdescriptor(di);
@@ -286,7 +312,7 @@ int vzctl_delete_snapshot(const char *ve_private, const char *guid)
 
 int vzctl_merge_snapshot(const char *ve_private, const char *guid)
 {
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct ploop_disk_images_data *di;
 	int ret;
 	struct ploop_merge_param param = {};
@@ -301,7 +327,7 @@ int vzctl_merge_snapshot(const char *ve_private, const char *guid)
 	di = ploop_alloc_diskdescriptor();
 	if (di == NULL)
 		return VZ_RESOURCE_ERROR;
-	GET_DISK_DESCRIPTOR(fname, ve_private)
+	GET_DISK_DESCRIPTOR(fname, ve_private);
 	ret = VZCTL_E_MERGE_SNAPSHOT;
 	if (ploop_read_diskdescriptor(fname, di)) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -322,13 +348,27 @@ err:
 
 int ve_private_is_ploop(const char *private)
 {
-	char image[MAXPATHLEN];
+	char image[PATH_MAX];
 
 	snprintf(image, sizeof(image), "%s/%s/root.hdd",
 			private, VZCTL_VE_ROOTHDD_DIR);
 	return stat_file(image);
 }
 
+int check_ploop_size(unsigned long size)
+{
+	const unsigned long max_size = /* 2T - 2G - 1M, in Kb */
+		(2ull << 30) - (2ull << 20) - (1 << 10);
+
+	if (size < max_size)
+		return 0;
+
+	logger(-1, 0, "Error: diskspace is set too big for ploop: %lu KB "
+			"(max size is %lu KB)", size, max_size - 1);
+	return -1;
+
+}
+
 /* Convert a CT to ploop layout
  * 1) mount CT
  * 2) create & mount image
@@ -364,6 +404,8 @@ int vzctl_env_convert_ploop(vps_handler *h, envid_t veid,
 		logger(-1, 0, "Error: diskspace not set");
 		return VZ_DISKSPACE_NOT_SET;
 	}
+	if (check_ploop_size(dq->diskspace[1]) < 0)
+		return VZ_DISKSPACE_NOT_SET;
 
 	snprintf(new_private, sizeof(new_private), "%s.ploop", fs->private);
 	if (make_dir_mode(new_private, 1, 0600) != 0)
