@@ -16,6 +16,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
@@ -30,6 +31,7 @@
 #include "vzerror.h"
 #include "logger.h"
 #include "vzsyscalls.h"
+#include "util.h"
 
 static inline int setublimit(uid_t uid, unsigned long resource,
 	const unsigned long *rlim)
@@ -85,6 +87,11 @@ if (ub->name == NULL) {							\
 	{
 		CHECK_UB(physpages);
 		CHECK_UB(swappages);
+		if (!is_vswap_mode()) {
+			logger(-1, 0, "Error: detected vswap CT config but "
+					"kernel does not support vswap");
+			ret = VZ_BAD_KERNEL;
+		}
 		return ret;
 	}
 	/* else
@@ -154,7 +161,7 @@ int get_ub_resid(char *name)
 	return -1;
 }
 
-const char *get_ub_name(unsigned int res_id)
+static const char *get_ub_name(unsigned int res_id)
 {
 	int i;
 
@@ -414,8 +421,12 @@ int vps_read_ubc(envid_t veid, ub_param *ub)
 
 int is_vswap_config(const ub_param *param)
 {
+	/* Dirty hack: treat INT_MAX (i.e. 32 bit LONG_MAX) as unlimited.
+	 * Required for old CTs migrated from 32 bit to 64 bit host.
+	 */
 	return  (param != NULL) &&
 		(param->physpages != NULL) &&
-		(param->physpages[1] != LONG_MAX);
+		(param->physpages[1] != LONG_MAX) &&
+		(param->physpages[1] != INT_MAX);
 
 }
