@@ -10,7 +10,6 @@
 #include <string.h>
 #include <limits.h>
 #include <sys/ioctl.h>
-#include <sys/param.h>
 #include <linux/vzcalluser.h>
 #include <linux/cpt_ioctl.h>
 #include <ploop/libploop.h>
@@ -44,7 +43,7 @@ static void vzctl_get_snapshot_dumpfile(const char *private, const char *guid,
 static int is_snapshot_supported(const char *ve_private)
 {
 	if (! ve_private_is_ploop(ve_private)) {
-		logger(-1, 0,"Snapshot feature is only available "
+		logger(-1, 0, "Snapshot feature is only available "
 				"for ploop-based CTs");
 		return 0;
 	}
@@ -55,11 +54,11 @@ int vzctl_env_create_snapshot(vps_handler *h, envid_t veid,
 		const fs_param *fs,
 		const struct vzctl_snapshot_param *param)
 {
-	int ret, run;
+	int ret, run = 0;
 	cpt_param cpt = {};
 	char guid[39];
-	char fname[MAXPATHLEN];
-	char tmp[MAXPATHLEN];
+	char fname[PATH_MAX];
+	char tmp[PATH_MAX];
 	struct ploop_snapshot_param image_param = {};
 	struct ploop_merge_param merge_param = {};
 	struct ploop_disk_images_data *di = NULL;
@@ -87,7 +86,7 @@ int vzctl_env_create_snapshot(vps_handler *h, envid_t veid,
 		}
 	}
 	logger(0, 0, "Creating snapshot %s", guid);
-	GET_DISK_DESCRIPTOR(fname, fs->private)
+	GET_DISK_DESCRIPTOR(fname, fs->private);
 	if (ploop_read_diskdescriptor(fname, di)) {
 		logger(-1, 0, "Failed to read %s", fname);
 		goto err;
@@ -102,9 +101,8 @@ int vzctl_env_create_snapshot(vps_handler *h, envid_t veid,
 		logger(-1, 0, "Failed to store %s", tmp);
 		goto err;
 	}
-	run = vps_is_run(h, veid);
-	if (run == -1)
-		goto err1;
+	if (!(param->flags & SNAPSHOT_SKIP_SUSPEND))
+		run = vps_is_run(h, veid);
 	/* 1 freeze */
 	if (run) {
 		ret = vps_chkpnt(h, veid, fs, CMD_SUSPEND, &cpt);
@@ -144,9 +142,10 @@ err2:
 	if (ret)
 		logger(-1, 0, "Rollback failed, ploop_merge_snapshot %s: %s [%d]",
 				guid, ploop_get_last_error(), ret);
+
+err1:
 	if (run)
 		cpt_cmd(h, veid, fs->root, CMD_CHKPNT, CMD_RESUME, 0);
-err1:
 	unlink(tmp);
 
 err:
@@ -163,10 +162,10 @@ int vzctl_env_switch_snapshot(vps_handler *h, envid_t veid,
 {
 	int ret, run;
 	cpt_param cpt = {};
-	char fname[MAXPATHLEN];
-	char tmp[MAXPATHLEN];
+	char fname[PATH_MAX];
+	char tmp[PATH_MAX];
 	char prev_top_guid[39];
-	char dumpfile[MAXPATHLEN];
+	char dumpfile[PATH_MAX];
 	struct vzctl_snapshot_tree *tree = NULL;
 	struct ploop_disk_images_data *di = NULL;
 
@@ -193,7 +192,7 @@ int vzctl_env_switch_snapshot(vps_handler *h, envid_t veid,
 		logger(-1, 0, "Unable to find snapshot by uuid %s", guid);
 		goto err;
 	}
-	GET_DISK_DESCRIPTOR(fname, fs->private)
+	GET_DISK_DESCRIPTOR(fname, fs->private);
 	ret = ploop_read_diskdescriptor(fname, di);
 	if (ret) {
 		logger(-1, 0, "Failed to read %s", fname);
@@ -278,8 +277,8 @@ int vzctl_env_delete_snapshot(vps_handler *h, envid_t veid,
 		const fs_param *fs, const char *guid)
 {
 	int ret;
-	char fname[MAXPATHLEN];
-	char tmp[MAXPATHLEN];
+	char fname[PATH_MAX];
+	char tmp[PATH_MAX];
 	struct vzctl_snapshot_tree *tree = NULL;
 
 	if (!is_snapshot_supported(fs->private))
@@ -304,8 +303,7 @@ int vzctl_env_delete_snapshot(vps_handler *h, envid_t veid,
 	}
 	logger(0, 0, "Deleting snapshot %s", guid);
 	vzctl_del_snapshot_tree_entry(tree, guid);
-	GET_SNAPSHOT_XML(tmp, fs->private);
-	strcat(tmp, ".tmp");
+	GET_SNAPSHOT_XML_TMP(tmp, fs->private);
 	ret = vzctl_store_snapshot_tree(tmp, tree);
 	if (ret) {
 		logger(-1, 0, "Failed to store %s", tmp);
@@ -324,7 +322,7 @@ int vzctl_env_delete_snapshot(vps_handler *h, envid_t veid,
 					fname);
 	}
 
-	// move sbapshot.xml on place
+	// move snapshot.xml to its place
 	GET_SNAPSHOT_XML(fname, fs->private);
 	if (rename(tmp, fname))
 		logger(-1, 0, "Failed to rename %s %s", tmp, fname);
@@ -352,7 +350,7 @@ static void print_snapshot_data(struct vzctl_snapshot_data *data)
 
 int vzctl_env_list_snapshot_tree(const char *ve_private)
 {
-	char fname[MAXPATHLEN];
+	char fname[PATH_MAX];
 	struct vzctl_snapshot_tree *tree = NULL;
 	int i, ret = 0;
 
