@@ -47,7 +47,7 @@
 extern struct mod_action g_action;
 extern int do_enter(vps_handler *h, envid_t veid, const char *root,
 			int argc, char **argv);
-extern int console_attach(vps_handler *h, envid_t veid);
+extern int do_console_attach(vps_handler *h, envid_t veid, int ttyno);
 
 static struct option set_opt[] = {
 	{"save",	no_argument, NULL, PARAM_SAVE},
@@ -558,6 +558,7 @@ static int parse_snapshot_create_opt(envid_t veid, int argc, char **argv,
 	{"uuid", required_argument, NULL, PARAM_SNAPSHOT_GUID},
 	{"name", required_argument, NULL, PARAM_SNAPSHOT_NAME},
 	{"description", required_argument, NULL, PARAM_SNAPSHOT_DESC},
+	{"skip-suspend", no_argument, NULL, PARAM_SNAPSHOT_SKIP_SUSPEND},
 	{ NULL, 0, NULL, 0 }
 	};
 
@@ -588,6 +589,10 @@ static int parse_snapshot_delete_opt(envid_t veid, int argc, char **argv,
 	ret = parse_opt(veid, argc, argv, opt, param);
 	free(opt);
 
+	if (ret == 0 && param->snap.guid == NULL)
+		return vzctl_err(VZ_INVALID_PARAMETER_SYNTAX, 0,
+			"Invalid syntax: snapshot id is missing");
+
 	return ret;
 }
 
@@ -846,7 +851,7 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 		if (cmd_p->res.fs.private_orig != NULL) {
 			free(cmd_p->res.fs.private_orig);
 			cmd_p->res.fs.private_orig = NULL;
-			logger(-1, 0,"Unable to change VE_PRIVATE "
+			logger(-1, 0, "Unable to change VE_PRIVATE "
 					"on a running container");
 			return VZ_VE_RUNNING;
 		}
@@ -960,6 +965,28 @@ static int enter(vps_handler *h, envid_t veid, const char *root,
 	return do_enter(h, veid, root, argc, argv);
 }
 
+static int console_attach(vps_handler *h, envid_t veid, int argc, char **argv)
+{
+	int tty = -1;
+
+	if (argc > 1)
+		return vzctl_err(VZ_INVALID_PARAMETER_SYNTAX, 0,
+				"Invalid syntax: too many parameters!");
+
+	if (argc == 1) {
+		if (parse_int(argv[0], &tty) != 0)
+			goto err;
+		if (tty < 0)
+			goto err;
+	}
+
+	return do_console_attach(h, veid, tty);
+
+err:
+	return vzctl_err(VZ_INVALID_PARAMETER_VALUE, 0,
+			"Invalid tty number: %s", argv[0]);
+}
+
 static int exec(vps_handler *h, act_t action, envid_t veid, const char *root,
 		int argc, char **argv)
 {
@@ -1040,6 +1067,7 @@ static int restore(vps_handler *h, envid_t veid, vps_param *g_p,
 
 	cmd = cmd_p->res.cpt.cmd;
 	merge_vps_param(g_p, cmd_p);
+	cmd_p->res.cpt.dumpdir = g_p->res.cpt.dumpdir;
 	if (cmd == CMD_KILL || cmd == CMD_RESUME)
 		return cpt_cmd(h, veid, g_p->res.fs.root,
 				CMD_RESTORE, cmd, cmd_p->res.cpt.ctx);
@@ -1249,6 +1277,12 @@ int run_action(envid_t veid, act_t action, vps_param *g_p, vps_param *vps_p,
 		else
 			ret = set(h, veid, g_p, vps_p, cmd_p);
 		if (cmd_p->opt.save == YES) {
+			if (ret) {
+				logger(-1, 0, "Error: failed to apply "
+						"some parameters, not saving "
+						"configuration file!");
+				break;
+			}
 			get_vps_conf_path(veid, fname, sizeof(fname));
 			/* Warn if config does not exist */
 			if (!stat_file(fname))
@@ -1273,7 +1307,7 @@ int run_action(envid_t veid, act_t action, vps_param *g_p, vps_param *vps_p,
 		ret = enter(h, veid, g_p->res.fs.root, argc, argv);
 		break;
 	case ACTION_CONSOLE:
-		ret = console_attach(h, veid);
+		ret = console_attach(h, veid, argc, argv);
 		break;
 	case ACTION_EXEC:
 	case ACTION_EXEC2:
